package com.myfirm;

import org.drools.KnowledgeBase;
import org.drools.KnowledgeBaseFactory;
import org.drools.builder.KnowledgeBuilder;
import org.drools.builder.KnowledgeBuilderError;
import org.drools.builder.KnowledgeBuilderErrors;
import org.drools.builder.KnowledgeBuilderFactory;
import org.drools.builder.ResourceType;
import org.drools.io.ResourceFactory;
import org.drools.runtime.StatefulKnowledgeSession;

/**
 * inits the rule flow
 */
public class RuleFlowProcess {
	private StatefulKnowledgeSession ksession;

	public void init() {
		KnowledgeBuilder kbuilder = KnowledgeBuilderFactory.newKnowledgeBuilder();
		kbuilder.add(ResourceFactory.newClassPathResource("threadSafeTest.rf"), ResourceType.DRF);
		kbuilder.add(ResourceFactory.newClassPathResource("testRules1.drl"), ResourceType.DRL);
		kbuilder.add(ResourceFactory.newClassPathResource("testRules2.drl"), ResourceType.DRL);
		kbuilder.add(ResourceFactory.newClassPathResource("testRules3.drl"), ResourceType.DRL);
		kbuilder.add(ResourceFactory.newClassPathResource("testRules4.drl"), ResourceType.DRL);

		KnowledgeBuilderErrors errors = kbuilder.getErrors();
		if (errors.size() > 0) {
			StringBuilder errorString = new StringBuilder();
			for (KnowledgeBuilderError error : errors) {
				errorString.append(error);
			}
			throw new RuntimeException(errorString.toString());
		}

		KnowledgeBase kbase = KnowledgeBaseFactory.newKnowledgeBase();
		kbase.addKnowledgePackages(kbuilder.getKnowledgePackages());
		ksession = kbase.newStatefulKnowledgeSession();
	}

	public StatefulKnowledgeSession getSession() {
		return this.ksession;
	}
}
